package Mentat::Reporter::Cache;
use strict;
use warnings;

#*******************************************************************************
# DOCUMENTATION SECTION
#*******************************************************************************

=head1 NAME

Mentat::Reporter::Cache

=head1 SYNOPSIS

 use Mentat::Reporter::Cache;

=head1 DESCRIPTION



=head1 AUTHOR

 Jan Mach
 Cesnet, z.s.p.o
 jan.mach@cesnet.cz
 http://www.cesnet.cz

=head1 COPYRIGHT

This program is free software; you can redistribute
it and/or modify it under the same terms as Perl itself.

The full text of the license can be found in the
LICENSE file included with this module.

=head1 SEE ALSO

perl(1).

=head1 FUNCTION REFERENCE

=over 4

=cut

#*******************************************************************************
# LIBRARY LOADING SECTION
#*******************************************************************************

#-- Perl core modules ---------------------------------------------------------#
use Carp;
use Scalar::Util 'blessed';

#use Data::Dumper; #-+-> DEVEL ONLY <-+-#
#use Smart::Comments; #-+-> DEVEL ONLY <-+-#

#-- Perl CPAN modules ---------------------------------------------------------#

#-- Custom application modules ------------------------------------------------#

#*******************************************************************************
# CONSTANTS AND GLOBAL VARIABLES DEFINITION SECTION
#*******************************************************************************

#-- Constants -----------------------------------------------------------------#

#-- Static public class variables (our) ---------------------------------------#

#-- Static protected class variables (my) -------------------------------------#

#*******************************************************************************
# INITIALIZATION AND CLEANUP SECTION
#*******************************************************************************

#-- Module initializations ----------------------------------------------------#
BEGIN {
    use vars qw($VERSION $DEVEL);
    $VERSION = '0.1';
    $DEVEL   = 0;
}


#-- Module clean-up code (global destructor) ----------------------------------#
END {

}

#*******************************************************************************
# IMPLEMENTATION SECTION
#*******************************************************************************

=item new() [PUBLIC,STATIC]

  Usage     : my $instance = Mentat::Reporter::Cache->new();
  Purpose   : Create and return reference to the new instance
  Arguments : Same as the the _init() method
  Returns   : Mentat::Reporter::Cache reference on success, croaks on failure
  Throws    : Dies, if not invoked on class
  Comments  : Internally uses _init() method, subclasses should never overload this method.
  See Also  : _init() method

=cut

sub new
{
    my $class = shift;
    confess "Class method not invoked on class" if blessed($class);
    ### Creating Mentat::Reporter::Cache instance...
    my $self = bless ({}, $class);
    return $self->_init(@_);
}

=item DESTROY() [PUBLIC]

  Usage     : This method must not be used directly
  Purpose   : Class destructor
  Arguments : None
  Returns   : Nothing
  Throws    : Dies, if not invoked on instance

=cut

sub DESTROY()
{
    my $self = shift;
    confess "Instance method not invoked on object instance" unless blessed($self);
    ### Destroying Mentat::Reporter::Cache instance...
}

#-------------------------------------------------------------------------------
# Private interface
#-------------------------------------------------------------------------------

# _init [PROTECTED]
#
#  Usage     : return $self->_init(@_);
#  Purpose   : Initialize the new Mentat::Reporter::Cache instance
#  Arguments : Unknown see the description in appropriate subclass
#  Returns   : Mentat::Reporter::Cache $self reference
#  Throws    : Dies, if not invoked on instance or given invalid arguments
#  Comments  : This method must never be called directly, it is supposed to be overloaded by subclasses.

sub _init
{
    my $self = shift;
    confess "Method needs to be implemented in subclass";
}

=pod

=back

=cut

1;
